@@ -156,23 +156,35 @@ def connection(**kwargs):
     if not isinstance(auth_url, list):
         auth_url = [auth_url]
     for u in auth_url:
+        # Include SSL / TLS, if requested.
+        server_args = {
+            "allowed_referral_hosts": [("*", True)],
+            "get_info": ldap3.NONE,
+            "connect_timeout": settings.LDAP_AUTH_CONNECT_TIMEOUT,
+        }
+        if settings.LDAP_AUTH_USE_TLS:
+            server_args["tls"] = ldap3.Tls(
+                ciphers="ALL",
+                version=settings.LDAP_AUTH_TLS_VERSION,
+            )
         server_pool.add(
             ldap3.Server(
                 u,
-                allowed_referral_hosts=[("*", True)],
-                get_info=ldap3.NONE,
-                connect_timeout=settings.LDAP_AUTH_CONNECT_TIMEOUT,
+                **server_args,
             )
         )
     # Connect.
     try:
+        connection_args = {
+            "user": username,
+            "password": password,
+            "auto_bind": False,
+            "raise_exceptions": True,
+            "receive_timeout": settings.LDAP_AUTH_RECEIVE_TIMEOUT,
+        }
         c = ldap3.Connection(
             server_pool,
-            user=username,
-            password=password,
-            auto_bind=False,
-            raise_exceptions=True,
-            receive_timeout=settings.LDAP_AUTH_RECEIVE_TIMEOUT,
+            **connection_args,
         )
     except LDAPException as ex:
         logger.warning("LDAP connect failed: {ex}".format(ex=ex))
@@ -180,9 +192,6 @@ def connection(**kwargs):
         return
     # Configure.
     try:
-        # Start TLS, if requested.
-        if settings.LDAP_AUTH_USE_TLS:
-            c.start_tls(read_server_info=False)
         # Perform initial authentication bind.
         c.bind(read_server_info=True)
         # If the settings specify an alternative username and password for querying, rebind as that.
